@@ -43,10 +43,16 @@ Version: %s
 
 usage: ragtag.py <command> [options]
     
-    commands:
-      correct         correct contig misassemblies 
-      scaffold        scaffold contigs
+    assembly improvement:
+      correct         misassembly correction 
+      scaffold        synteny scaffolding
+      
+    file utilities:
+      agp2fasta       build a FASTA file from an AGP file
+      agpcheck        check for valid AGP file format
       updategff       update gff intervals
+      
+    
 
     options:
       -c, --citation  
@@ -80,6 +86,14 @@ usage: ragtag.py <command> [options]
             subcmd = ["ragtag_update_gff.py"] + sys.argv[2:]
             subprocess.call(subcmd)
 
+        elif cmd == "agp2fasta":
+            subcmd = ["ragtag_agp2fasta.py"] + sys.argv[2:]
+            subprocess.call(subcmd)
+
+        elif cmd == "agpcheck":
+            subcmd = ["ragtag_agpcheck.py"] + sys.argv[2:]
+            subprocess.call(subcmd)
+
         else:
             print(description)
             print("\n** unrecognized command: %s" % cmd)
