@@ -121,7 +121,7 @@ def get_median_read_coverage(output_path, num_threads, overwrite_files):
         cs += covs[i]
         if cs >= mid:
             return i
-    raise ValueError()
+    raise ValueError("Unable to calculate read coverage. Check SAM/BAM files and stats file.")
 
 
 def run_samtools(output_path, num_threads, overwrite_files):
@@ -327,8 +327,8 @@ def main():
     parser = argparse.ArgumentParser(description='Reference-guided misassembly correction', usage="ragtag.py correct <reference.fa> <query.fa>")
 
     cor_options = parser.add_argument_group("correction options")
-    cor_options.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file. must not be gzipped.")
-    cor_options.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file. must not be gzipped.")
+    cor_options.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file (can be uncompressed or bgzipped)")
+    cor_options.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file (can be uncompressed or bgzipped)")
     cor_options.add_argument("-f", metavar="INT", type=int, default=1000, help="minimum unique alignment length [1000]")
     cor_options.add_argument("--remove-small", action="store_true", default=False, help="remove unique alignments shorter than -f")
     cor_options.add_argument("-q", metavar="INT", type=int, default=10, help="minimum mapq (NA for Nucmer alignments) [10]")
@@ -341,7 +341,7 @@ def main():
     cor_options.add_argument("--gff", metavar="<features.gff>", type=str, default="", help="don't break sequences within gff intervals")
 
     io_options = parser.add_argument_group("input/output options")
-    io_options.add_argument("-o", metavar="STR", type=str, default="ragtag_output", help="output directory [ragtag_output]")
+    io_options.add_argument("-o", metavar="PATH", type=str, default="ragtag_output", help="output directory [./ragtag_output]")
     io_options.add_argument("-w", action='store_true', default=False, help="overwrite intermediate files")
     io_options.add_argument("-u", action='store_true', default=False, help="add suffix to unaltered sequence headers")
     io_options.add_argument("--debug", action='store_true', default=False, help=argparse.SUPPRESS)
@@ -391,7 +391,11 @@ def main():
     val_window_size = args.v
 
     # I/O options
-    output_path = args.o.replace("/", "").replace(".", "")
+    output_path = args.o
+    if not os.path.isdir(output_path):
+        os.mkdir(output_path)
+    output_path = os.path.abspath(output_path) + "/"
+
     overwrite_files = args.w
     remove_suffix = not args.u
     if remove_suffix:
@@ -488,12 +492,6 @@ def main():
         if min_cov != -1:
             raise ValueError("--min-cov must be >=0")
 
-    # Get the current working directory and output path.
-    cwd = os.getcwd()
-    output_path = cwd + "/" + output_path + "/"
-    if not os.path.exists(output_path):
-        os.mkdir(output_path)
-
     # Debugging options
     debug_mode = args.debug
     debug_non_fltrd_file = output_path + "ragtag.correction.debug.unfiltered.paf"
@@ -504,9 +502,9 @@ def main():
     # Align the query to the reference.
     log("Mapping the query genome to the reference genome")
     if genome_aligner == "minimap2":
-        al = Minimap2Aligner(reference_file, query_file, genome_aligner_path, mm2_params, output_path + "c_query_against_ref", in_overwrite=overwrite_files)
+        al = Minimap2Aligner(reference_file, [query_file], genome_aligner_path, mm2_params, output_path + "c_query_against_ref", in_overwrite=overwrite_files)
     else:
-        al = NucmerAligner(reference_file, query_file, genome_aligner_path, nucmer_params, output_path + "c_query_against_ref", in_overwrite=overwrite_files)
+        al = NucmerAligner(reference_file, [query_file], genome_aligner_path, nucmer_params, output_path + "c_query_against_ref", in_overwrite=overwrite_files)
     al.run_aligner()
 
     # If alignments are from Nucmer, convert from delta to paf.
@@ -581,10 +579,10 @@ def main():
         log("Aligning reads to query sequences.")
         if not os.path.isfile(output_path + "c_reads_against_query.s.bam"):
             if val_reads_tech == "sr":
-                al = Minimap2SAMAligner(query_file, " ".join(read_files), read_aligner_path, "-ax sr -t " + str(num_threads),
+                al = Minimap2SAMAligner(query_file, read_files, read_aligner_path, "-ax sr -t " + str(num_threads),
                                         output_path + "c_reads_against_query", in_overwrite=overwrite_files)
             elif val_reads_tech == "corr":
-                al = Minimap2SAMAligner(query_file, " ".join(read_files), read_aligner_path, "-ax asm5 -t " + str(num_threads),
+                al = Minimap2SAMAligner(query_file, read_files, read_aligner_path, "-ax asm5 -t " + str(num_threads),
                                         output_path + "c_reads_against_query", in_overwrite=overwrite_files)
             else:
                 raise ValueError("'-T' must be either 'sr' or 'corr'.")
@@ -640,6 +638,8 @@ def main():
     ]
     run_o(cmd, output_path + qf_pref + ".corrected.fasta")
 
+    log("Goodbye")
+
 
 if __name__ == "__main__":
     main()
