@@ -246,8 +246,8 @@ def read_genome_alignments(aln_file, query_blacklist, ref_blacklist):
 def main():
     parser = argparse.ArgumentParser(description='Reference-guided scaffolding', usage="ragtag.py scaffold <reference.fa> <query.fa>")
     scaf_options = parser.add_argument_group("scaffolding options")
-    scaf_options.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file. must not be gzipped.")
-    scaf_options.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file. must not be gzipped.")
+    scaf_options.add_argument("reference", metavar="<reference.fa>", nargs='?', default="", type=str, help="reference fasta file (can be uncompressed or bgzipped)")
+    scaf_options.add_argument("query", metavar="<query.fa>", nargs='?', default="", type=str, help="query fasta file (can be uncompressed or bgzipped)")
     scaf_options.add_argument("-e", metavar="<exclude.txt>", type=str, default="", help="list of reference headers to ignore")
     scaf_options.add_argument("-j", metavar="<skip.txt>", type=str, default="", help="list of query headers to leave unplaced")
     scaf_options.add_argument("-f", metavar="INT", type=int, default=1000, help="minimum unique alignment length [1000]")
@@ -263,7 +263,7 @@ def main():
     scaf_options.add_argument("-m", metavar="INT", type=int, default=100000, help="maximum inferred gap size [100000]")
 
     io_options = parser.add_argument_group("input/output options")
-    io_options.add_argument("-o", metavar="STR", type=str, default="ragtag_output", help="output directory [ragtag_output]")
+    io_options.add_argument("-o", metavar="PATH", type=str, default="ragtag_output", help="output directory [./ragtag_output]")
     io_options.add_argument("-w", action='store_true', default=False, help="overwrite intermediate files")
     io_options.add_argument("-u", action='store_true', default=False, help="add suffix to unplaced sequence headers")
     io_options.add_argument("--debug", action='store_true', default=False, help=argparse.SUPPRESS)
@@ -305,7 +305,11 @@ def main():
     num_threads = args.t
 
     # I/O options
-    output_path = args.o.replace("/", "").replace(".", "")
+    output_path = args.o
+    if not os.path.isdir(output_path):
+        os.mkdir(output_path)
+    output_path = os.path.abspath(output_path) + "/"
+
     overwrite_files = args.w
     remove_suffix = not args.u
     if remove_suffix:
@@ -355,12 +359,6 @@ def main():
     if mm2_params == mm2_default:
         mm2_params += " -t " + str(num_threads)
 
-    # Get the current working directory and output path
-    cwd = os.getcwd()
-    output_path = cwd + "/" + output_path + "/"
-    if not os.path.exists(output_path):
-        os.mkdir(output_path)
-
     # Debugging options
     debug_mode = args.debug
     debug_non_fltrd_file = output_path + "ragtag.scaffolds.debug.unfiltered.paf"
@@ -371,9 +369,9 @@ def main():
     # Align the query to the reference
     log("Mapping the query genome to the reference genome")
     if aligner == "minimap2":
-        al = Minimap2Aligner(reference_file, query_file, aligner_path, mm2_params, output_path + "query_against_ref", in_overwrite=overwrite_files)
+        al = Minimap2Aligner(reference_file, [query_file], aligner_path, mm2_params, output_path + "query_against_ref", in_overwrite=overwrite_files)
     else:
-        al = NucmerAligner(reference_file, query_file, aligner_path, nucmer_params, output_path + "query_against_ref", in_overwrite=overwrite_files)
+        al = NucmerAligner(reference_file, [query_file], aligner_path, nucmer_params, output_path + "query_against_ref", in_overwrite=overwrite_files)
     al.run_aligner()
 
     # If alignments are from Nucmer, need to convert from delta to paf
@@ -523,6 +521,8 @@ def main():
     ]
     run_o(cmd, output_path + "ragtag.scaffolds.stats")
 
+    log("Goodbye")
+
 
 if __name__ == "__main__":
     main()
